documentationtools.ReSTTOCItem
==============================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem

.. autoclass:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depth
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depthwise_inventory
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.graph_order
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.improper_parentage
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.name
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.parent
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.proper_parentage
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.rest_format
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.root
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.text
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__copy__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__deepcopy__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__eq__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__getstate__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__ne__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__repr__
      ~abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__setstate__

Bases
-----

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.text
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__setstate__
   :noindex:
